@@ -125,9 +125,9 @@ This formatter outputs the issues as HTML.
         <b>Confidence: </b>HIGH<br>
         <b>File: </b><a href="examples/yaml_load.py"
         target="_blank">examples/yaml_load.py</a> <br>
-        <b>More info: </b><a href="http://docs.openstack.org/developer/bandit/
+        <b>More info: </b><a href="https://bandit.readthedocs.io/en/latest/
         plugins/yaml_load.html" target="_blank">
-        http://docs.openstack.org/developer/bandit/plugins/yaml_load.html</a>
+        https://bandit.readthedocs.io/en/latest/plugins/yaml_load.html</a>
         <br>
 
     <div class="code">
@@ -150,15 +150,22 @@ This formatter outputs the issues as HTML.
 .. versionadded:: 0.14.0
 
 """
+from __future__ import absolute_import
 
-import cgi
 import logging
 import sys
 
+import six
+
 from bandit.core import docs_utils
 from bandit.core import test_properties
 from bandit.formatters import utils
 
+if not six.PY2:
+    from html import escape as html_escape
+else:
+    from cgi import escape as html_escape
+
 LOG = logging.getLogger(__name__)
 
 
@@ -342,15 +349,15 @@ pre {
     for index, issue in enumerate(issues):
         if not baseline or len(issues[issue]) == 1:
             candidates = ''
-            safe_code = cgi.escape(issue.get_code(lines, True).
-                                   strip('\n').lstrip(' '))
+            safe_code = html_escape(issue.get_code(lines, True).
+                                    strip('\n').lstrip(' '))
             code = code_block.format(code=safe_code)
         else:
             candidates_str = ''
             code = ''
             for candidate in issues[issue]:
-                candidate_code = cgi.escape(candidate.get_code(lines, True).
-                                            strip('\n').lstrip(' '))
+                candidate_code = html_escape(candidate.get_code(lines, True).
+                                             strip('\n').lstrip(' '))
                 candidates_str += candidate_issue.format(code=candidate_code)
 
             candidates = candidate_block.format(candidate_list=candidates_str)
